\name{boot.ROC.penfix}
\alias{boot.ROC.penfix}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Estimation of true diagnostic capacity of microarray data (without censoring) using the cross-validation, the 0.632 and the 0.632+ estimators of ROC curves
}
\description{
This function performs estimations of ROC curves according to different bootstrap-based approaches. The signature is obtained by using a logistic model with lasso penalty.  The tuning parameter is given by the user, in opposition to the function \code{boot.ROC}.
}
\usage{
boot.ROC.penfix(status, features, N.boot,
 precision, fold.cv, lambda1)
}
\arguments{
  \item{status}{A numeric vector with the indicators of the disease (e.g. 0=disease-free, 1=disease).}
  \item{features}{A matrix with the observed features. The number of raw is the number of individuals (length of the argument \code{status}).}
  \item{N.boot}{Number of bootstrap iterations.}
  \item{precision}{The quintiles of the predictor used for computing each point of the ROC curve.}
  \item{fold.cv}{The fold for cross-validation (determination of the tuning parameter of the lasso penalty at each bootstrap iteration).}
  \item{lambda1}{The fixed values of the tuning parameters for L1 (lasso).} 
}
\details{
This function computes ROC curve (without censoring data) based on the 0.632+ estimator. At each bootstrap iteration, a logistic model with lasso penalty is estimated. The value of the tuning parameter is fixed by the user. The complete methodology is explained by Danger and Foucher (2012) in the context of incomplete data (right censoring). Nevertheless the application of this method is straightforward when the false positive/negative rates are simply obtained by the corresponding observed proportions. 
}
\value{
The function returns a list.  \code{AUC} is a data frame. The raw(s) represent(s) the value(s) of the prognostic time. \code{train} is the mean of the areas obtained by using the individuals included in the bootstrap samples (training). \code{valid} is the mean of the areas obtained by using the individuals not included in the bootstrap samples (cross-validation). \code{s632} is the mean of the areas obtained by using the simple 0.632 estimator. \code{p632} is the mean of the areas obtained by using the 0.632+ estimator. \code{ROC.Apparent}, \code{ROC.CV}, \code{ROC.632} and \code{ROC.632p} are 4 data frames in which the false negative and positive rates are presented respectively for the 4 estimators: apparent, bootstrap and cross-validation, bootstrap 0.632 and bootstrap 0.632+. These rates correspond to the threashols in \code{cut.values}. \code{Coef} is a vector of the regression coefficients obtained in the Cox model with lasso penalty obtained by using all subjects. The value of the tuning parameter is equal to \code{Lambda} (this value is not estimated). This model is contained in the object \code{Model}. This object is obtained by using the function penalized() in the R package penalized. Please, look at the corresponding help for more details about the object \code{Model}. Finally, the signature represents the prognostic score for each subject, i.e. the sum of the regression multiplied by the value of the features.
}
\references{
R. Danger and Y. Foucher. Time dependent ROC curves for the estimation of true prognostic capacity of microarray data. Statistical Applications in Genetics and Molecular Biology.  2012. In press.}
\author{
Y. Foucher <Yohann.Foucher@univ-nantes.fr>
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{

# import and attach the data example

data(DLBCLpatients)
data(DLBCLgenes)

# WARNING for this example: we only consider the status at the end of
# the follow-up without considering the time-to-event  (this assumption
# can be acceptable if the follow-up time is the same for all subjects,
# if there is no censoring).

res <- boot.ROC.penfix(status=DLBCLpatients$f,
 features=DLBCLgenes, N.boot=5,
 precision=seq(0.01, 0.99, by=0.04),
 fold.cv=5, lambda=50)

# The regression coefficients associated
# with the Cox model with lasso penalty
coefficients(res$Model, "all")
res$Coef

# The distribution of the prognostic score
hist(res$Signature, nclass=30, main="",
 xlab="Observed values of the multivariate signature")

# Illustrations of the ROC curve
plot(res$ROC.Apparent$FPR, 1-res$ROC.Apparent$FNR,
 type="b", pch=1, lty=1,
 ylab="True Positive Rates",
 xlab="False Positive Rates") 
lines(res$ROC.CV$FPR, 1-res$ROC.CV$FNR,
 type="b", pch=2, lty=2) 
lines(res$ROC.632$FPR, 1-res$ROC.632$FNR,
 type="b", pch=3, lty=3) 
lines(res$ROC.632p$FPR, 1-res$ROC.632p$FNR,
 type="b", pch=4, lty=4) 
legend("bottomright",
 paste(c("Apparent", "CV", "0.632", "0.632+"),
 "curve (AUC=", round(res$AUC,2), ")"), pch=1:4,
 lty=1:4)

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ 0.632 }
\keyword{ bootstrap }
\keyword{ ROC curve }
